==> vdcpy-0.0.2.tar.gz: vdcpy-0.0.2/tests/user_tests/update_user_test.py <==
import unittest

import vdcpy.user as vdc_user
import tests.utils.user_util as user_util

class PutUserTest(unittest.TestCase):

    def setUp(self):
        # Delete all unittest users.
        user_util.delete_unittest_users()
        # Add a unittest user.
        user_util.add_unitest_user()
    
    def test_successful_put_user_name(self):
        # Get the id of the unittest user.
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']
        # Update the unittest user.
        response = vdc_user.update_user(
            user_id, {'name': 'unittest_user_updated'})
        self.assertEqual(type(response), dict)
        self.assertEqual(response['name'], 'unittest_user_updated')

    def test_successful_put_user_email(self):
        # Get the id of the unittest user.
        user_list = vdc_user.get_users(email='test@test.test')
        user_id = user_list[0]['id']
        # Update the unittest user.
        response = vdc_user.update_user(
            user_id, {'email': 'fake@fake.fake'})
        self.assertEqual(type(response), dict)
        self.assertEqual(response['email'], 'fake@fake.fake')

    def test_successful_put_user_position(self):
        # Get the id of the unittest user.
        user_list = vdc_user.get_users(email='test@test.test')
        user_id = user_list[0]['id']
        # Update the unittest user.
        response = vdc_user.update_user(
            user_id, {'position': 'unittest_position_updated'})
        self.assertEqual(type(response), dict)
        self.assertEqual(response['position'], 'unittest_position_updated')

    def test_successful_put_user_organization(self):
        # Get the id of the unittest user.
        user_list = vdc_user.get_users(email='test@test.test')
        user_id = user_list[0]['id']
        # Update the unittest user.
        response = vdc_user.update_user(
            user_id, {'organization': 'unittest_organization_updated'})
        self.assertEqual(type(response), dict)
        self.assertEqual(response['organization'], 'unittest_organization_updated')

    def tearDown(self):
        # Delete all unittest users.
        user_util.delete_unittest_users()

==> vdcpy-0.0.7.tar.gz: vdcpy-0.0.7/tests/user_tests/update_user_test.py <==
import unittest

import vdcpy.user as vdc_user
import tests.utils.user_util as user_util

class PutUserTest(unittest.TestCase):

    def setUp(self):
        # Delete all unittest users.
        user_util.delete_unittest_users()
        # Add a unittest user.
        user_util.add_unittest_user()
    
    def test_successful_put_user_name(self):
        # Get the id of the unittest user.
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']
        # Update the unittest user.
        response = vdc_user.update_user(
            user_id, {'name': 'unittest_user_updated'})
        self.assertEqual(type(response), dict)
        self.assertEqual(response['name'], 'unittest_user_updated')

    def test_successful_put_user_email(self):
        # Get the id of the unittest user.
        user_list = vdc_user.get_users(email='test@test.test')
        user_id = user_list[0]['id']
        # Update the unittest user.
        response = vdc_user.update_user(
            user_id, {'email': 'fake@fake.fake'})
        self.assertEqual(type(response), dict)
        self.assertEqual(response['email'], 'fake@fake.fake')

    def test_successful_put_user_position(self):
        # Get the id of the unittest user.
        user_list = vdc_user.get_users(email='test@test.test')
        user_id = user_list[0]['id']
        # Update the unittest user.
        response = vdc_user.update_user(
            user_id, {'position': 'unittest_position_updated'})
        self.assertEqual(type(response), dict)
        self.assertEqual(response['position'], 'unittest_position_updated')

    def test_successful_put_user_organization(self):
        # Get the id of the unittest user.
        user_list = vdc_user.get_users(email='test@test.test')
        user_id = user_list[0]['id']
        # Update the unittest user.
        response = vdc_user.update_user(
            user_id, {'organization': 'unittest_organization_updated'})
        self.assertEqual(type(response), dict)
        self.assertEqual(response['organization'], 'unittest_organization_updated')

    def tearDown(self):
        # Delete all unittest users.
        user_util.delete_unittest_users()
